summaryrefslogtreecommitdiff
path: root/tests/LightyTest.pm
diff options
context:
space:
mode:
authorGlenn Strauss <gstrauss@gluelogic.com>2017-03-18 22:35:31 -0400
committerGlenn Strauss <gstrauss@gluelogic.com>2017-03-19 23:48:50 -0400
commitaa14493e4788f602d86defb3fa6509d41f01664b (patch)
treebb3d24fb1c3c681a2a60c8ed7a5453a63a3e8eec /tests/LightyTest.pm
parent1804ccbd6da9a16600f226526e7bd61f5b01596f (diff)
downloadlighttpd-git-aa14493e4788f602d86defb3fa6509d41f01664b.tar.gz
[tests] reduce time waiting for backends to start
reduce time spent waiting for backends to start tests check for active listening port before proceeding test runs now complete in about 2/3 the time
Diffstat (limited to 'tests/LightyTest.pm')
-rw-r--r--tests/LightyTest.pm4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/LightyTest.pm b/tests/LightyTest.pm
index f1865896..74caea1e 100644
--- a/tests/LightyTest.pm
+++ b/tests/LightyTest.pm
@@ -122,10 +122,10 @@ sub wait_for_port_with_proc {
my $self = shift;
my $port = shift;
my $child = shift;
- my $timeout = 10*10; # 10 secs (valgrind might take a while), select waits 0.1 s
+ my $timeout = 10*50; # 10 secs (valgrind might take a while), select waits 0.02 s
while (0 == $self->listening_on($port)) {
- select(undef, undef, undef, 0.1);
+ select(undef, undef, undef, 0.02);
$timeout--;
# the process is gone, we failed